import pandas as pd
from scipy import integrate

conso = pd.read_csv("output_conso.csv")
conso["time"] = pd.to_datetime(conso["time"], format="%Y-%m-%dT%H:%M:%S")
conso.set_index("time", inplace=True)
conso = conso.resample('M')['value'].agg(['max'])

temp = pd.read_csv("output_temp.csv")
temp["time"] = pd.to_datetime(temp["time"], format="%Y-%m-%dT%H:%M:%S")
temp.set_index("time", inplace=True)
temp = temp.resample('D').mean()

gaz = pd.read_csv("output_gaz.csv")
gaz["time"] = pd.to_datetime(gaz["time"], format="%Y-%m-%dT%H:%M:%S")
gaz.set_index("time", inplace=True)
gaz = gaz.resample('D').max()

TV = pd.read_csv("output_TV.csv")
TV["time"] = pd.to_datetime(TV["time"], format="%Y-%m-%dT%H:%M:%S")
TV.set_index("time", inplace=True)
TV = TV.resample("D").apply(integrate.trapz)

cuisine = pd.read_csv("output_cuisine.csv")
cuisine["time"] =  pd.to_datetime(cuisine["time"], format="%Y-%m-%dT%H:%M:%S")
cuisine.set_index("time", inplace=True)
cuisine = cuisine.resample("D").apply(integrate.trapz)

lavelinge = pd.read_csv("output_lavelinge.csv")
lavelinge["time"] = pd.to_datetime(lavelinge["time"], format="%Y-%m-%dT%H:%M:%S")
lavelinge.set_index("time", inplace=True)
lavelinge = lavelinge.resample("W").apply(integrate.trapz)




df_conso = pd.merge(temp, conso,  how='outer', on='time')
df_gaz = pd.merge(temp, gaz,  how='outer', on='time')
df_TV = pd.merge(temp, TV,  how='outer', on='time')
df_cuisine = pd.merge(temp, cuisine, how='outer', on='time')
df_lavelinge = pd.merge(temp, lavelinge, how='outer', on='time')

dfs = [df_conso, df_gaz, df_TV, df_cuisine, df_lavelinge]
dfs_name = ["conso", "gaz", "TV", "cuisine", "lave-linge"]

for i, df in enumerate(dfs):
    df.dropna(inplace=True)
    df.rename(columns={"max": "conso", "value": dfs_name[i]}, inplace=True)
    # if df[i] == "gaz":
    #     df["diff"] = df.gaz.diff()
    if dfs_name[i] == "conso":
        df = df[(df["conso"] < 20000) & (df["conso"] > 0)]
    if dfs_name[i] == "lave-linge":
        df = df[df["value_y"] > 0]
    df.to_csv("data_{}.csv".format(dfs_name[i]))



